@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 1998, 1999, 2000, 2008, 2010 Sergey Poznyakoff
+   Copyright (C) 1998-2016 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 static void
 dicod_xidle(dico_stream_t str, int argc, char **argv)
 {
-    stream_printf(str, "110 %lu second(s)\r\n", inactivity_timeout);
+    stream_printf(str, "110 %lu second(s)\n", inactivity_timeout);
 }
     
 void
